package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````W!D!`#0```!HD0````0`!30`(``)
M`"@`'``;``$``'"8A@``F(8!`)B&`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"DA@``I(8```4```````$`
M`0```,R-``#,C0(`S(T"`$0"``!P$@``!@```````0`"````V(T``-B-`@#8
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DS(T`
M`,R-`@#,C0(`-`(``#0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`HK=OGGAO<:,0MTV$#3<8V%J\1:($
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4):0$0`0``!`4,)`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(,`@!`D`D``D#I-"0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%0```!6````````````````````
M`````%<```!;````7````%T`````````7@``````````````8```````````
M````8@```&0```!E````9@```&D```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUV;^-PF4+NH6H)0]:?(L>H(6)D!WZIG)MB
MT/J"["SVBVM_FGR'\)9\%8PES.\+4?F0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@
M^TE7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M``$``````````````"`````=```````````````@````+```````````````
M(``````#`````````````!(```#@`0`````````````2````;@(`````````
M````$@```$L"`````````````!(````A!````)`"```````@`!<`F@$`````
M````````$@```$0"`````````````!(```"*`0``$!4!```````2````I@,`
M`!"0`@``````$``8``<"`````````````!(````I`@`````````````2````
M800```R0`@`$````$0`7`+$"`````````````!(```#9!```-#,!`(`#```2
M``T`^P,``$`E`0`D````$@`-``<#`````````````!(````/`@``````````
M```2````P@(`````````````$@```.,#```\H`(``````!``&`#&`P``````
M```````2````!P0``-@K`0!<!P``$@`-`#L$```<(@$`T````!(`#0#N`P``
M&"4!`"@````2``T`-@(`````````````$@````("`````````````!(```!C
M`0`````````````2````G@(`````````````$@```(4$``"P10$`1`$``!(`
M#0`:`P``$)`"``0````A`!@`PP$`````````````$@```,\!````````````
M`!(````4!```<$0!`$`!```2``T`8`(`````````````$@```-L#```0D`(`
M`````!``%P![`@`````````````2````8P```#@7`0``````$@```#X"````
M`````````!(```#2`@`````````````2````_`$`````````````$@```,H!
M`````````````!(````;`P``$)`"``0````A`!@`<`0``#R@`@``````$``8
M`+L"```@D`(`!````!$`&`"%`P``5$<!``0````2``T`;@$`````````````
M$@```$H!`````````````!(```!1!```]$8!`&`````2``T`L`0``,PJ`0`,
M`0``$@`-`!@"`````````````!(````E!```W!D!```````2``T`@P``````
M````````$@```(\``````````````!(```"0`@`````````````2````TP``
M`!B0`@`!````$0`8`%D"`````````````!(````L!```=$<!``0````1``\`
MCP0``!"0`@``````$``8`-D"`````````````!(```#Q`@`````````````2
M````1@``````````````$@```.```````````````!(```";!```Z"$!`#0`
M```2``T`$P$`````````````$@```&L$```\H`(``````!``&`"C!```\"(!
M`"@"```2``T`I```````````````$@```",#`````````````!(```#H`0``
M```````````2````?`$`````````````$@```+(``````````````!(```#$
M```````````````2````\0```!20`@`$````$0`8`!D#```0D`(`!````!$`
M&``\`0`````````````2````9P(`````````````$@```.(#```\H`(`````
M`!``&`#"!```+"H!`(@````2``T`=```````````````$@```*D"````````
M`````!(```#\```````````````2````'P0```"0`@``````$``7`.,"````
M`````````!(````U`P``U(T"``0````1`!0`M`,``+0J`0`8````$@`-`+@!
M`````````````!(```"E`0`````````````2````%`,``,`7`0`<`@``$@`-
M`!@!`````````````!(```#0!```]$,!`'P````2``T`R0(`````````````
M$@```(D"`````````````!(```!U`@`````````````2````L0$`````````
M````$@```/D"`````````````!(```!2`@`````````````2````>`0``&0E
M`0#(!```$@`-`!T!`````````````!(````P`@`````````````2````SP,`
M`+0V`0!8`0``$@`-`%0``````````````!(```!:`0`````````````2````
ME0,``.PB`0`$````$@`-`"D!``"T%@$``````!(`````7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;W!E;C8T`')E860`
M7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`
M8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')D
M=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT
M9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER
M`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D
M9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?
M<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D+G-O
M+C``;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]L:6)C7V-S=5]F
M:6YI`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?96YD
M7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?
M=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?
M96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I
M;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L
M96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`
M`````````````@`#``(``@`!`````@````$``@`"``$``@`!``$``@`"``(`
M`0`"``$``0`!``(``@````(``0`"``,``P`!``(``0`"`````@`"``,``P`"
M``$``@`!```````!``$``@`!```````"`````@`!``$``@`"```````!````
M`0`!`````@`#`````````````@````(``0`!`````@````$``@`$``$`````
M``$``@`!``(``@`"``(``@`"``$````"``$```````$````!``$`<0,``!``
M```@````%&EI#0``!`#O!`````````$``0!7`P``$````"`````4:6D-```#
M`.\$`````````0`!`&<#```0`````````!1I:0T```(`[P0```````#\CP(`
M%0(``-2-`@`45@``$)`"`!1,```4D`(`%$L``!B0`@`4.0``()`"`!0N``#T
MC@(`%@8``/B.`@`6!```_(X"`!87````CP(`%BL```2/`@`6%0``"(\"`!8^
M```,CP(`%EL``!"/`@`610``%(\"`!9>```8CP(`%@L``!R/`@`67P``((\"
M`!91```DCP(`%D(``"B/`@`6.```+(\"`!9B```PCP(`%C0``#2/`@`61@``
M.(\"`!8.```\CP(`%AL``$"/`@`6,```1(\"`!9-``!(CP(`%ET``$R/`@`6
M20``4(\"`!98``!4CP(`%@4``%B/`@`660``7(\"`!92``!@CP(`%B$``&2/
M`@`68```:(\"`!83``!LCP(`%C$``'"/`@`6`@``=(\"`!8'``!XCP(`%AP`
M`'R/`@`6)```@(\"`!9G``"$CP(`%BD``(B/`@`6-@``C(\"`!8B``"0CP(`
M%E4``)2/`@`6-P``F(\"`!8=``"<CP(`%F4``*"/`@`63@``I(\"`!9J``"H
MCP(`%C\``*R/`@`69```L(\"`!8)``"TCP(`%B8``+B/`@`60```O(\"`!8*
M``#`CP(`%F$``,2/`@`64P``R(\"`!8Z``#,CP(`%D@``-"/`@`6)P``U(\"
M`!8]``#8CP(`%DH``-R/`@`6:```X(\"`!80``#DCP(`%@T``.B/`@`6*```
M[(\"`!8J``#PCP(`%AX``/2/`@`6%```^(\"`!9'```(0"WI8@$`ZPB`O>@$
MX"WE!."?Y0[@C^`(\+[E2'H!``#&C^(7RHSB2/J\Y0#&C^(7RHSB0/J\Y0#&
MC^(7RHSB./J\Y0#&C^(7RHSB,/J\Y0#&C^(7RHSB*/J\Y0#&C^(7RHSB(/J\
MY0#&C^(7RHSB&/J\Y0#&C^(7RHSB$/J\Y0#&C^(7RHSB"/J\Y0#&C^(7RHSB
M`/J\Y0#&C^(7RHSB^/F\Y0#&C^(7RHSB\/F\Y0#&C^(7RHSBZ/F\Y0#&C^(7
MRHSBX/F\Y0#&C^(7RHSBV/F\Y0#&C^(7RHSBT/F\Y0#&C^(7RHSBR/F\Y0#&
MC^(7RHSBP/F\Y0#&C^(7RHSBN/F\Y0#&C^(7RHSBL/F\Y0#&C^(7RHSBJ/F\
MY0#&C^(7RHSBH/F\Y0#&C^(7RHSBF/F\Y0#&C^(7RHSBD/F\Y0#&C^(7RHSB
MB/F\Y0#&C^(7RHSB@/F\Y0#&C^(7RHSB>/F\Y0#&C^(7RHSB</F\Y0#&C^(7
MRHSB:/F\Y0#&C^(7RHSB8/F\Y0#&C^(7RHSB6/F\Y0#&C^(7RHSB4/F\Y0#&
MC^(7RHSB2/F\Y0#&C^(7RHSB0/F\Y0#&C^(7RHSB./F\Y0#&C^(7RHSB,/F\
MY0#&C^(7RHSB*/F\Y0#&C^(7RHSB(/F\Y0#&C^(7RHSB&/F\Y0#&C^(7RHSB
M$/F\Y0#&C^(7RHSB"/F\Y0#&C^(7RHSB`/F\Y0#&C^(7RHSB^/B\Y0#&C^(7
MRHSB\/B\Y0#&C^(7RHSBZ/B\Y0#&C^(7RHSBX/B\Y0#&C^(7RHSBV/B\Y0#&
MC^(7RHSBT/B\Y0#&C^(7RHSBR/B\Y0#&C^(7RHSBP/B\Y0#&C^(7RHSBN/B\
MY0#&C^(7RHSBL/B\Y0#&C^(7RHSBJ/B\Y0#&C^(7RHSBH/B\Y0#&C^(7RHSB
MF/B\Y0#&C^(7RHSBD/B\Y0#&C^(7RHSBB/B\Y0#&C^(7RHSB@/B\Y0#&C^(7
MRHSB>/B\Y0#&C^(7RHSB</B\Y0#&C^(7RHSB:/B\Y0#&C^(7RHSB8/B\Y0#&
MC^(7RHSB6/B\Y0#&C^(7RHSB4/B\Y0#&C^(7RHSB2/B\Y0#&C^(7RHSB0/B\
MY0`````P0"WI)-!-XMPQG^44`(WE$!"-Y0P@C>44`(WB$!"-X@P@C>(`,)/E
M'#"-Y0`PH..4___KM"&?Y;0!G^4"$*#AU`L`ZZPQG^4`4-/E``!5XZ1!GQ4)
M```:9O__ZYPAG^4``%#C$`""Y5P```J(09_E//__ZP``E.7<___K?5?`Y0``
ME.79___K`#"@X0``E.7&(]/E`B""X\8CP^73___K%#"=Y04P@^('`7/CQB/0
MY0$@@N/&(\#E1P``B@,!H.%2___K."&?Y1`0G>4L09_E!""2Y0`PH.$``)'E
M"""#Y2`AG^4``(/E#""#Y1@!G^44()WE!`"#Y0$`4N,$`*#C!`"$Y00`0<(,
MP(/"`@&`P`@PA.4#``#:!."QY0$`4.$$X*SE^___&@T!@N(`$*#C`!"-Y0,@
M@N(`$8/GS!"?Y1``E.5S___K`%!0XA(```H0`)3E&___Z[0`G^48$(WB:0``
MZP``4.,/```*$`"4Y?_^_^MA___K;#"?Y0`@D^4<,)WE`B`SX``PH.,5```:
M!0"@X230C>(P@+WH$`"4Y7W__^L`4*#AZ/__Z@P`E.4``%#C`0``"DT'`.OJ
M___J4`"?Y1@0C>)/``#K``!0XPP`A.7D__\*]O__ZES__^L!`*#C(?__Z^K^
M_^O4C0(`M!8!`#@7`0`8D`(`%)`"`"B0`@`(D`(`/$L!`#A+`0!X(0$``$D!
M`*!(`0``L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E
M_?[_ZUS__^M41P$`P!<!`/1&`0`4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'X
M_O_JP'0!`!0!```8`)_E&#"?Y0``4^$>_R\!$#"?Y0``4^,>_R\!$_\OX1"0
M`@`0D`(``````"0`G^4D$)_E`#!!X*,?H.%#$8'@P1"PX1[_+P$0,)_E``!3
MXQ[_+P$3_R_A$)`"`!"0`@``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C@___K
M`3"@XP`PQ.40@+WH))`"`.;__^KP1RWI`)!0XBH```JT,)_E`("3Y0``6.,H
M```*`%#9Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`F.4``%3C#```"@A@
MH.$$`*#A!2"@X0D0H.$3___K``!0XP(``!H%,-3G/0!3XPL```H$0+;E``!4
MX_/__QH$`*#A\(>]Z`E0H.$!,/7E``!3XST`4Q/[__\:"5!%X.;__^H(8$;@
M`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"4"@X>W__^H(0*#AZ___ZA"0`@!,
M,9_E\$$MZ0!04.)XT$WB`#"3Y70PC>4`,*#C`@``"@`PU>4``%/C!P``&B`Q
MG^4`()/E=#"=Y0(@,^``,*#C0@``&GC0C>+P@;WH?/[_ZP!`4.+T__\*^'"?
MY00`H.'1_O_K``!0XRH```H3,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*
M$S#0Y2X`4^,E```*!0"@X8'^_^L`@*#A!@"@X7[^_^L``(C@`@"`XFG^_^L'
M,*#A`"#@XP$0H.,$8(WE`%"-Y0!@H.&#_O_K"""-X@80H.$#`*#CN_[_ZP$`
M<.,&`*#A`P``"A@PG>4/.@/B`0E3XQ(```HU_O_K!@"@X1+^_^L$`*#AIO[_
MZP``4./4__\:!`"@X;K^_^L%`*#A%O[_Z[___^H!,-;E+@!3X];__QH",-;E
M``!3X\7__PK2___JK/__Z^O__^H:_O_KU(T"`$!(`0`00"WI<-!-XG@PG^4`
M$*#A`$"@X0T@H.$#`*#C`#"3Y6PPC>4`,*#CG?[_ZP``4.,``*`3!```&A`P
MG>4/.@/B"@I3XP$)4Q,'```*-#"?Y0`@D^5L,)WE`B`SX``PH.,'```:<-"-
MXA"`O>@"$*#C!`"@X6;^_^L0#V_AH`*@X?'__^KV_?_KU(T"`!!`+>D`0*#A
M*_[_ZP$P0.(#,(3@`P!4X0,@H#$#```Z)```Z@0`4N$",*#A(0``"@(PH.$!
M$%+D+P!1X_C__PH#`%3A&P``*@$P0^(#`%3A&@``"@`@T^4O`%+C^?__&@$P
M0^(#``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__.@0@0N`",(+B`0I3
MXP8``(H!.J#C`2""X@00H.$\`)_EQ?W_ZS0`G^40@+WH``"@XQ"`O>@#`%3A
MY___&@`PU.4O`%/C`@``"A!`O>@0`)_EO/W_ZA!`O>@(`)_EN?W_ZCR0`@!(
M2`$`$$@!`/!`+>D!VDWB#-!-X@$ZC>(!4*#AV!"?Y=@@G^4`$)'E!!"#Y0`0
MH.,`8*#A!!"-XL0`G^4$,(/BO/W_ZP#`4.(B``#:"#"-X@%`3.($X(/@!#!>
MY0``4^.@,)_E`'"3Y1@``!H``%3C&@``"@0@H.$O$*#C!`"-X@/^_^L``%#C
M%```"@<`H.$L_O_K!#"@X00@C>(&$*#A$/[_ZP$ZC>),()_E!#"#X@`0DN4`
M()/E`1`RX``@H.,,```:`=J-X@S0C>+P@+WH#$"@X>;__^HH,)_E`'"3Y0<`
MH.$7_O_K!2"@X080H.&-_?_KZO__ZGS]_^O4C0(`_P\``$Q(`0`4D`(`\$<M
MZ0%`H.$`,-'EY"&?Y0C03>(]`%/C`4"!`@!0H.$$`*#A`""2Y00@C>4`(*#C
MI/W_ZPT0H.$`8*#A!0"@X<3^_^L`D%#B/0``"IW]_^L``%;A-```F@!PG>68
M@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`
M4A/[__\:!3!#X`(`AN(#`(#@`&"8Y7;]_^L``%#C!P"&YQ8```H`$)WE`""8
MY04`H.$!,-#D`1&2YP``4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C
M``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!,.+E^___&N0PG^4`
M()/E!#"=Y0(@,^``,*#C,P``&@C0C>+PA[WH`9!)X@$PU.0``%/C`3#IY?O_
M_QKQ___JL("?Y0!PF.4`,)?E``!3XR,```H',*#A!""SY0D0H.$``%+C`9")
MXOK__QH#$('B`1&@X8`PG^4`()/E``!2XP\``!H!(*#C`0"@X0`@@^4Y_?_K
M`*!0XMK__PH'$*#A"7&@X0<@H.'N_/_K`*"(Y0$PB>(`(*#C`R&*YP"0C>6F
M___J!P"@X0W]_^L``%#C`*"@X0``B.7*__\*"7&@X?+__^H#D*#A"!"@X^#_
M_^KZ_/_KU(T"`!"0`@`HD`(`$$`MZ0C03>)$0)_E``"4Y8C]_^L``)3EAOW_
MZS0PG^4T()_E-!"?Y3K]_^L``)3E@/W_ZR@PG^4`P*#C)""?Y200G^4($(WH
M2OW_ZPC0C>(0@+WH%)`"`*B%`0`0%0$`7$@!`#1+`0`T,P$`>$@!`!PPG^40
M0"WI``"3Y6W]_^L00+WH##"?Y0P@G^4,$)_E(/W_ZA20`@"HA0$`$!4!`%Q(
M`0`P0"WI`MI-XAS03>*L()_E`CJ-XA0P@^(`()+E`""#Y0`@H./W_/_KE!"?
MY90PG^64()_E\`#-X0$0H.,,`(WB!?W_ZP$:C>(!*J#C$!"!X@P`C>+*_/_K
M`$!0X@!0H+,)``"Z`0"$XMK\_^L`4%#B!0``"@$:C>($(*#A$!"!XIC\_^L`
M,*#C!##%YP(ZC>(H()_E%#"#X@`0DN4`()/E`1`RX``@H.,#```:!0"@X0+:
MC>(<T(WB,("]Z)[\_^O4C0(`G$@!`)!(`0`!$```RO__ZO!/+>E"W4WB!-!-
MXO@AG^5!/8WB`%"@X0%@H.'L`9_E$!"-XCPP@^(`()+E`""#Y0`@H./H_?_K
M+Q"@XP!`H.$%`*#AQOS_ZP``4.,.```*O`&?Y040H.$)___K!0"@X4$]C>*@
M(9_E/#"#X@`0DN4`()/E`1`RX``@H.-A```:0MV-X@30C>+PC[WH!0"@X:W\
M_^M\$9_E`("@X08`H.'B_/_K`*!0XNC__PH`,-KE9)&?Y5QQG^4``%/C?&"-
MXCD```H``%3C!```"@H0H.$$`*#A.?S_ZP``4.,I```*"@"@X9C\_^L!$$#B
M`."@X0$PVN<O`%/C`3"*X`H``!H"`$#B``"*X`,00>`#`$#@`R"@X0"PH.,!
MX(/@`+##Y@'`<N4O`%SC^O__"@$PB.(.X(/@`0I>X\3__ZK<()_E"3"@X0$0
MH.,$((WE!@"@X0$JH.,(4(WE`*"-Y8G\_^L0((WB!A"@X0,`H./!_/_K``!0
MXP,``!H@,)WE#SH#X@()4^,4```*!Q"@X0``H..F_/_K``!0XP"@H.&K__\*
M`##:Y0``4^/%__\:``!4XP(```H`,-3E+@!3XP(```I<H)_E`>"@X]?__^H!
M,-3E``!3X^O__PKX___J`1"@XP8`H.&+_/_K``!0X^7__QH<`)_E!A"@X:'^
M_^L&`*#A%?S_ZY7__^H6_/_KU(T"`*!(`0"L2`$`O$@!`,!(`0!(2`$`$$@!
M```PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^$`,%#B
M`P``"@`PT^4``%/C````"@G^_^H``)_E^OO_ZA!(`0`P0"WI--!-XF3DG^5D
M-)_E","-X@`PD^4L,(WE`#"@XP\`ONA01)_E4%2?Y0\`K.@/`+[H#P"LZ``P
MGN6P,,SA!!"-X@0`H.%&_?_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0
MXP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J]$.?Y>Q3G^4$$(WB
M!`"@X3+]_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$
M,(/B!""3Y0``4N,$((/D^___&NW__^JH0Y_EG%.?Y000C>($`*#A'OW_ZP``
M4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2
MXP0@@^3[__\:[?__ZEQ#G^5,4Y_E!!"-X@0`H.$*_?_K``!0XPP```H$$)WE
M`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM
M___J$$.?Y?Q2G^4$$(WB!`"@X?;\_^L``%#C#```"@00G>4`()7E`3&"X`0`
MD^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^K$0I_EK%*?
MY000C>($`*#AXOS_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G
M\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZGA"G^5<4I_E!!"-X@0`H.'.
M_/_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKM___J+$*?Y0Q2G^4$$(WB!`"@X;K\_^L``%#C#```
M"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D
M^___&NW__^K@09_EO%&?Y000C>($`*#AIOS_ZP``4.,,```*!!"=Y0`@E>4!
M,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZI1!
MG^5L49_E!!"-X@0`H.&2_/_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0
MXP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J2$&?Y1Q1G^4$$(WB
M!`"@X7[\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$
M,(/B!""3Y0``4N,$((/D^___&NW__^H$$(WB^`"?Y6S\_^L`$%#B`0``"MP`
MG^62_?_K!!"-XN``G^5E_/_K`!!0X@$```K4`)_EB_W_ZP00C>+,`)_E7OS_
MZP`04.(,```*G`"?Y83]_^NX$)_EB`"?Y8']_^MH,)_E`""3Y2PPG>4"(#/@
M`#"@XQ,``!HTT(WB,("]Z`00C>*,`)_E3/S_ZP`04.("```*6`"?Y7+]_^OL
M___J=!"?Y0H@H.,9`(WB;?O_ZP``4./F__\:-`"?Y2,0C>)H_?_KXO__ZM_Z
M_^NTA0$`U(T"`,A(`0`0D`(`U$@!`-Q(`0#H2`$`\$@!``!)`0"@2`$`#$D!
M`!A)`0`D20$`K$@!`#!)`0!$20$`%$@!`%A)`0"(20$`:$D!`'Q)`0`00"WI
M"-!-XFQ`G^5L,)_E``"4Y0`PD^4$,(WE`#"@XP$`<.,'```*4#"?Y0`@D^4$
M,)WE`B`SX``PH.,-```:"-"-XA"`O>@T`)_E#1"@X1+\_^L``%#C!```"@``
MT.4P`%#C``!0$P$`H!,``*`#``"$Y>O__^JK^O_K")`"`-2-`@`,20$`$$`M
MZ87Z_^M^^O_K``!0XP``D!40@+WH<$`MZ1C03>+L,)_E`%"@X1`0C>+D`)_E
M`#"3Y10PC>4`,*#C]?O_ZP!`4.(.```*`##4Y0``4^,+```*!1"@X63Z_^L`
M`%#C$@``"J@PG^4`()/E%#"=Y0(@,^``,*#C)```&AC0C>)P@+WHB#"?Y0`@
MD^44,)WE`B`SX``PH.,%$*`!=`"?!1H``!H8T(WB<$"]Z`/]_^H%`*#AL_K_
MZP!@H.$$`*#AL/K_ZP``AN`"`(#BF_K_ZT0PG^4`(.#C`1"@XQ@`C>D`4(WE
M-#"?Y0!`H.&T^O_K'#"?Y0`@D^44,)WE`B`SX``PH.,$$*`!"`"?!>3__PIC
M^O_KU(T"`(Q)`0"\2`$`P$@!`/!/+>D"V4WB_-!-XO`VG^7P%I_E`BF-X@`0
MD>7T$(+E`!"@X_0@@N(`<*#A!P"3Z(1`C>(,X(/B)%"#X@<`A.B<P(WB#P"^
MZ)!`C>(/`*SH`P">Z`,`C.@'`)7H!P"$Z!@0C>*@!I_EH?O_ZP!`4.("```*
M`##4Y0``4^,$`0`:'?K_ZQ;Z_^L`0%#BW0``"@!0E.4``%7CV0``"@4`H.%O
M^O_K@`"@X0$`@.):^O_K`"#5Y0``4N,`8*#A"P``"DB&G^4&0*#A!`"@X0`@
MC>4(,*#A`"#@XP$0H.-O^O_K`2#UY0)`A.(``%+C]?__&AP&G^6@4(WB`@``
MZ@0`E>0``%#C#0``"A@0C>)X^__K`$!0XOC__PH`,-3E``!3X_7__PK\^__K
M``!0X_+__PH$`*#A#OK_ZP!`4.(4```:`%"@XX20C>+X,(WB!3&#X'1`$^4`
M`%3C#```"@&`A>((@8G@`##4Y0``4^,'```*!`"@X>C[_^L!4(7B``!0XSL`
M`!H$0)CD``!4X_3__QH`0*#C!`"@X3'Z_^MTE9_E`*"@X08`H.$M^O_K``"*
MX`&K@.($H(KB"@"@X1;Z_^M4-9_E`"#@XP$0H.,(,(WE#&"-Y40UG^4`0(WE
M!)"-Y0"`H.$M^O_K!QV@XP@`H.$S^O_K`0!PXP,``!HD^O_K`!"0Y1$`4>.7
M```:&""-X@@0H.$#`*#C:/K_ZP!04.(8```*^!2?Y0`PE^7T))_E``"1Y0$0
MH.,`@(WE,OK_ZP!@H.,".8WBN"2?Y?0P@^(`$)+E`""3Y0$0,N``(*#C)@$`
M&@8`H.$"V8WB_-"-XO"/O>@$`*#AO?G_ZP!`4.*P__\*PO__ZB@PG>4/.@/B
M`0E3X^+__QHP0)WEEOG_ZP``5.'>__\:*#"=Y8,[H.&C.Z#A!PU3X]G__QH*
M`*#AU?G_ZQ@0C>(`8*#A6`2?Y0?[_^L``%#C@0``"@!`E^6C^?_K`!"@X00`
MH.$)_?_K`*!0XGH```H*`*#AV/G_ZP,`4.,`0*#A"P``F@0`0.(8%)_E``"*
MX&[Y_^L``%#C!0``&@0`5./%```*!$"*X`4P5.4O`%/CP0``"O!#G^4`,)3E
M`0!SXV<```H``%/C=```"MP3G^7<`Y_E#OS_Z[GY_^O4<Y_EU#.?Y0`@X.,!
M$*#C\(#-X0QPC>7$HY_E"`"-Y08`H.'$^?_K#@``ZK_Y_^L`,)#E$0!3XQ``
M`!JI^?_K`5"%X@HPH.$$(*#A`1"@XQ!PC>4,4(WE`,"@X08`H.$`$XWHM/G_
MZP<=H.,&`*#ANOG_ZP$`<.,`0*#AZO__"@@`H.%)^?_K&`.?Y080H.'H^__K
M!@"@X;S^_^N/___J!4"@X9!@C>+X,(WB!#&#X&@`$^4``%#C*@``"@%0A.(%
M@8;@`P``Z@0`F.0``%#C)```"@%0A>(8$(WBJ_K_ZP5`H.$`,%#B]O__"@`P
MT^4``%/C\___"D3Y_^L`4%#B#/__&N?__^JP`I_E`#"7Y=`BG^4``)#E!!"-
MY0"`C>4!$*#CG_G_ZP!@H.-K___JEO[_ZP(YC>)D(I_E]#"#X@`0DN4`()/E
M`1`RX``@H..1```:!`"@X0+9C>+\T(WB\$^]Z"GY_^H-`*#C4?G_ZW12G^53
M(*#C`&"@X?;^_^H`H)?E@O__ZD@"G^48$(WB?OK_ZP``4.,``(0%"```"@`P
MT.4``%/C,`!3$P$PH!,`,*`#`3"@$P`PA`4`,(05BO__&@H`H.$`$*#C-OG_
MZP!`4.*%__\*`E"@XP`PX.,1(.#C`%"-Y2;Y_^L&(*#C]!"-X@0`H.'C^/_K
M]##=Y0``4^,"```:]3#=Y4,`4^-````*`#"@XP`@H.,`,(WE!`"@X0`PH.,6
M^?_KH00`ZP!0H.$"``#J]!"-X@4`H.&[!`#K`BF@X_00C>($`*#AS?C_ZP`@
M4.+V___*!`"@X7KY_^L%$*#AM`"-X@`%`.OX,(WB,*!#XBRQG^6S4(WB"D"@
MX3%P0^(!(/7E!`"@X0LPH.$`((WE`1"@XP`@X.,E^?_K!0!7X0)`A.+U__\:
M)"&?Y0`0H.,,((WE\!#-Y2@QG^4`(.#C`1"@XP8`H.$(H(WE\(#-X1?Y_^MG
M___J!$"7Y0``5.,Z__\*!`"@X0+Y_^L#`%#C-O__F@0`0.+L$)_E``"$X)GX
M_^L``%#C!*"@`2___^KV,-WE00!3X[O__QKW,-WE0P!3X[C__QKX,-WE2`!3
MX[7__QKY,-WE10!3X[+__QH`,.#C!`"@X3D@X.,`4(WEROC_Z_00C>($`*#A
M*2"@XX?X_^MH()_E]#"-X@@PC>4,((WE;#"?Y0`@X.,!$*#C!@"@X020C>4`
M@(WEZ/C_ZSC__^J>^/_KV(4!`-2-`@"@2`$`I$D!`!1(`0!(2`$`N$D!`*Q)
M`0`@D`(`_$D!`%!*`0!82@$`")`"`(A)`0`,20$`-$L!`'A*`0"(2@$`P$D!
M`)Q)`0!H2@$`8$H!`/!/+>D,T$WB.%.?Y3@SG^4``)7E`#"3Y00PC>4`,*#C
M%?G_ZP!`H.$``)7E$OG_ZV@@U.4-$*#A`#"@X0P#G^5I(,/ET_G_ZP``4.,"
M```*`##0Y3$`4^.C```*<_S_ZP``E>4$^?_KY!*?Y0LPH.,!(*#CE_C_ZP``
M4..7```*$""0Y<QRG^4`H)7E&)"2Y00@E^4!`%+C+0``V@!`H.,)``#J$!"2
MY0@`H.$R^/_K!""7Y0``4.,B```:`D"$X@(`5.$&0*#A'@``J@H`H.'I^/_K
M`#"@XP0@H.$)$*#AQ/C_ZP"P4.(4```*`"";Y0@0E^4!8(3B"#"2Y0:!D>?_
M-,/CWSC#X_L\P^/_,,/C`0M3XP"@E>7A__\*"@"@X=7X_^L`$)OE`C"@XP`@
MH.-0^/_K`*"5Y0`0H.'9___J!""7Y0"@E>4!$$+B!`!1X4T```H*`*#AQ_C_
MZ_@1G^4#,*#C`2"@XUKX_^L`0%#B"@``"@``E>6_^/_K$#"4Y=@AG^4`$)/E
M-/C_ZQ`PE.4`,)/E"#"3Y0$%$^-=```:``"5Y;3X_^NT$9_E`S"@XP$@H.-'
M^/_K`$!0X@H```J@`9_E#1"@X7+Y_^L`8%#B``"5Y4@```JG^/_K$#"4Y08@
MH.$`$)/E'/C_ZP``E>6A^/_K`$"@X0``E>6>^/_K9!&?Y0$@H.-'^/_K7"&?
MY0`0H.$$`*#A$/C_ZP``E>65^/_K`""@XPT0H.$`,*#A/`&?Y6D@P^56^?_K
M``!0XP!`H.$,`(?E'```"@<=H.,$`*#A0_C_ZP$@@.(1`%#C`0!2$P`PH.$Q
M``"*V#"?Y0`@D^4$,)WE`B`SX``PH.,J```:#-"-XO"/O>@!`%+CK___V@%`
MH.,*`*#A=OC_ZPD0H.'&]__K!#"7Y0%`A.($`%/A`*"5Y?;__\JD___J"`"7
MY7;]_^L``%#C`$"@X0P`A^7<__\:F`"?Y1OX_^L`H)7E;'"?Y9G__^H!,-#E
M``!3XUG__PI7___J7OC_ZP@@E^40,)3E`!"2Y0``D^4)^O_KM/__Z@``E>56
M^/_K$#"4Y0`0D^4:^/_KF___ZKOW_^L(()?E/`"?Y0`0DN4$(*#A`?C_ZQ20
M`@#4C0(`\$@!`)Q*`0`HD`(`I$H!`*A*`0#,2@$`K$@!`+!*`0#(2@$`H$@!
M`-!*`0#T2@$`/#&?Y?!`+>D`<%#B#-!-X@`PD^4$,(WE`#"@XS,```H`,-?E
M``!3XS````JF^?_K`$"@X0`PU.4``%/C!0``"@$@A.(O`%/C`D"@`0$PTN0`
M`%/C^O__&NA@G^4`4%?B`5"@$P`PEN4!`'/C(P``"@``4^,`4*`#`5`%$@``
M5>,'```:N#"?Y0`@D^4$,)WE`B`SX``PH.,H```:#-"-XO"`O>@`,-?E``!3
MX_3__PJ4$)_E!""@XP0`H.'_]__K``!0X^[__QIT,)_E`""3Y00PG>4"(#/@
M`#"@XQ<``!H'`*#A#-"-XO!`O>C\^/_J6`"?Y6?W_^L`0*#AS/__ZDP`G^4-
M$*#APOC_ZP``4.,``(8%VO__"@`PT.4``%/C,`!3$P`PH`,!,*`3`#"&!=/_
M_PH!,*#C`#"&Y<[__^I7]__KU(T"``B0`@"X20$`$$@!``Q)`0``````R#N?
MY?!/+>FCWTWB0!"`XH!@@.(-(*#A`#"3Y80RC>4`,*#C`%"@XP3`$>4(X!'E
M"!"!XBPTH.'_/`/B+#R#X0Q$H.$,/(/A_T@$XC[/O^8$,(/A!@!1X0#`@N4$
M4(+E"#""Y0Q0@N40((+B[?__&@C`3>)^[XWB`#"@XPQ`H.$(8+SE<""4Y4B0
ME.5T$)3E3("4Y1APE.4<4)3E"2`BX`1`G.4($"'@!R`BX`8@(N`%$"'@!!`A
MX*)/H.&!0(3A`B"2X`0@@N$.`%SA\"C,X>G__QKX*I_E`%"0Y0`0G>4$H)#E
M(,"0Y0(0D>`,$)'@I<V@X1!`D.4(<)#E&&"0Y8K"C.$,D)#EA<*,X0'`G.`&
M$"3@)^&@X0<0`>`)[X[A!A`AX`'`G.`'CX[A"!"=Y0C@).`"$)'@)9&@X07@
M#N`$X"[@!A"1X`J?B>$%GXGA#A"1X!#@G>4)H"C@`N">X`R@"N`$X)[@"*`J
MX`J@GN`8X)WE[!V!X`+@GN`(X)[@;($IX`&`".`)@"C@"(">X"#@G>7AK8K@
M`N">X&$1H.$)D)[@;.$AX`K@#N!LX2[@#I"9X"C@G>7JC8C@`N">X&S!CN!J
MX2'@".`.X`'@+N`.P)S@,."=Y>B=B>`"X)[@:(&@X0$0GN!JX2C@">`.X.G-
MC.!JX2[@#A"1X.SM@>`X$)WE`A"1X&H1@>!IH2C@#*`*X`B@*N`*$)'@0*"=
MY6S!H.$"H)K@"(":X&FA+.`.H`K@[AV!X&FA*N`*@)C@X:V(X$B`G>4"@)C@
M:8&(X&Z1+.`!D`G@#)`IX`F`F.!0D)WE81&@X0*0F>`,P)G@;I$AX`J0">#J
MC8C@;I$IX`G`G.#HG8S@6,"=Y0+`G.!NP8S@:N$AX`C@#N`!X"[@#L"<X&#@
MG>5H@:#A`N">X`$0GN!JX2C@">`.X.G-C.!JX2[@#A"1X.SM@>!H$)WE`A"1
MX&H1@>!IH2C@#*`*X`B@*N`*$)'@<*"=Y6S!H.$"H)K@"(":X&FA+.`.H`K@
M[AV!X&FA*N`*@)C@X;V(X'B`G>6@H)WE`H"8X&F!B.!ND2S@`9`)X`R0*>`)
MD)C@@("=Y6$1H.$"@)C@#,"8X&Z!(>`+@`C@ZYV)X&Z!*.`(P)S@Z8V,X(C`
MG>4"P)S@;L&,X&OA(>`)X`[@`>`NX`[`G."0X)WE:9&@X0+@GN`!$)[@:^$I
MX`C@#N#HS8S@:^$NX`X0D>#L[8'@F!"=Y0(@D>!KL8+@:"$IX`P@`N`)("+@
M`K";X!@HG^5LP:#A`J":X.X=B^`)H)K@J+"=Y6B1+.`.D"G@"9":X`*PF^!H
ML8O@L*"=Y6Z!+.`!@"C@X9V)X`B`F^!A$:#A`J":X`R@FN"XL)WE;L$AX.F-
MB.`)P"S@#,":X`*PF^#HK8S@;N&+X&G!(>#`L)WE",`LX`S@GN!H@:#A`K";
MX,C`G>4!L)O@:1$HX.KMCN`*$"'@`1";X`+`G.#NO8'@:9&,X&H1*.#0P)WE
M#A`AX`&0F>!NX:#A`L"<X-@0G>4(@)S@:L$NX`O`+.`,@)C@`A"1X.N=B>#@
MP)WE:J&!X&L1+N`)$"'@Z8V(X`&@FN!ID:#A`L"<X.@0G>4.X)S@:\$IX`C`
M+.`,X)[@`A"1X.BMBN#PP)WE:[&!X&@1*>`*$"'@ZNV.X`&PF^!JH:#A`L"<
MX/@0G>4)D)S@:,$JX`[`+.`,D)G@`A"1X.Z]B^!H@8'@;A$JX`L0(>`!@)C@
M`!&=Y>N=B>`"$)'@:[&@X6[!*^`*H)'@"!&=Y0G`+.`,H)K@`A"1X.F-B.`0
MP9WE;N&!X&D1*^`($"'@Z*V*X`'@GN!H@:#A`L"<X!@1G>4+L)S@:<$HX.KM
MCN`*P"S@#+";X`(0D>!JP2C@:1&!X.Z=B^`@L9WE#L`LX`P0D>!NX:#A`K";
MX.G-@>`(@)O@:A$NX"BQG>4)$"'@`1"8X`*PF^!JH8O@:8$NX#"QG>7L'8'@
M#(`HX`B`FN!LH:#A`K";X.'-B.`.X)O@:8$JX#BQG>4!@"C@".">X`(@F^!I
MD8+@82$JX`P@(N#LC8[@`I"9X$#AG>7`)9_E;,&@X0+@GN`*X)[@8:&,X6&Q
M#.`(H`K@"Z"*X0K@GN!(H9WEZ)V)X`*PFN!HH8SAZ>V.X&&QB^`)H`K@:1&@
MX6B1#.`)D(KA4*&=Y0N0F>`"H)K@#,":X&BA@>%HL0'@#J`*X`N@BN$,P)K@
M6*&=Y>Z=B>`"L)K@;J&!X6BQB^`)H`K@Z8V,X&G!H.%ND0'@"9"*X6"AG>4+
MD)G@`J":X`$0FN!NH8SA;K$,X`B@"N`+H(KA`:":X&@1G>7HG8G@`K"1X&@1
MC.'IK8K@;K&+X`D0`>!IX:#A:)$,X`D0@>%PD9WE"Q"1X`*0F>`,P)G@:)&.
MX6BQ#N`*D`G@"Y")X0R0F>!XP9WEZAV!X`*PG.!HL8O@:H&.X>&=B>!AP:#A
M`8`(X&H1#N`!$(CA"Q"1X.F]@>"`$9WE:H$,X`(0D>`.$)'@:N&,X0G@#N`(
MX([A`>">X(@1G>7KC8[@`A"1X&JA@>!I$8SA:^&@X0L0`>!IL0S@"Q"!X0J@
MD>"0$9WE:;$.X`(0D>`,$)'@Z,V*X&FACN$(H`K@"Z"*X0&@FN"8$9WE:+$.
MX`(0D>!ID8'@:!&.X0P0`>#LK8K@"Q"!X0D0D>#JO8'@H!&=Y6S!H.$"$)'@
M#A"1X&CAC.%HD0S@"N`.X`G@CN$!D)[@J!&=Y>N=B>`"X)'@:A&,X6CACN`+
M$`'@:X&@X6JQ#.`+$('A#N"1X+`1G>5JL0C@`A"1X`P0D>#IS8[@:N&(X0G@
M#N`+X([A`1">X+CAG>5IL0C@`N">X&KACN#LK8'@:1&(X0P0`>`+$('A#N"1
MX,`1G>5LP:#A`A"1X`@0D>!I@8SA:;$,X`J`".`+@(CA!#"`Y0&`F.#($9WE
MZNV.X`(0D>!ID8'@:A&,X6JQ#.`.$`'@"Q"!X0F0D>#0$9WE[HV(X`(0D>!N
MX:#A#!"1X&K!CN%JL0[@",`,X`O`C.$!P)S@V!&=Y>B=B>`"()'@:!&.X6BQ
M#N`)$`'@:J&"X`L0@>'0(I_E"A"1X."AG>7IS8S@`J":X&F1H.'HL9WE#N":
MX.RM@>!H$2G@#!`AX`'@GN`"L)O@;!$IX&B!B^#PL9WE"A`AX.KMCN`!@)C@
M:J&@X0*PF^`)L)O@^!&=Y6R1*N`.D"G@"9";X`(0D>#NC8C@`+*=Y6S!@>!N
M$2K@"!`AX.B=B>`!P)S@:(&@X0*PF^`*L)O@"!*=Y6ZA*.`)H"K@"J";X`(0
MD>#IS8S@$+*=Y6[A@>!I$2C@#!`AX.RMBN`!X)[@;,&@X0*PF^`(L)O@&!*=
MY6F!+.`*@"C@"(";X`(0D>#J[8[@(+*=Y6F1@>!J$2S@#A`AX.Z-B.`!D)G@
M;N&@X0*PF^`,L)O@*!*=Y6K!+N`(P"S@#,";X`(0D>#HG8G@,+*=Y6JA@>!H
M$2[@"1`AX.G-C.`!H)K@:9&@X0*PF^`.L)O@.!*=Y6CA*>`,X"[@#N";X`(0
MD>#LK8K@0+*=Y6B!@>!L$2G@"A`AX.KMCN`!@)C@:J&@X0*PF^`)L)O@2!*=
MY6R1*N`.D"G@"9";X`(0D>#NC8C@4+*=Y6S!@>!N$2K@"!`AX.B=B>`!P)S@
M:(&@X0*PF^`*L)O@6!*=Y6ZA*.`)H"K@"J";X`(0D>#IS8S@8+*=Y6[A@>!I
M$2C@#!`AX.RMBN`!X)[@;,&@X0*PF^`(L)O@:8$LX.KMCN`*@"C@"(";X.Z-
MB.!H$IWE:&&&X`(0D>!ID8'@&&"`Y7`2G>5J82S@#F`FX`:0F>`"$)'@#!"1
MX.C-B>!NX:#A;$&$X&IA+N`00(#E>$*=Y0A@)N`&$)'@`B"4X`4@DN!JH8+@
M:"$NX.P=@>`,("+@(,"0Y0*@FN#A+8K@!Q"1X`S@GN`,,(#E%#"`Y1PP@.4`
M((#E"!"`Y2#@@.4D,(#E'#"?Y0`@D^6$,IWE`B`SX``PH.,!```:H]^-XO"/
MO>A=]/_KU(T"`)EY@EJAZ]ENW+P;C];!8LH00"WI@`"@XWST_^L.>Y_M`""@
MXP![@.T->Y_M>""`Y0)[@.T,>Y_M!'N`[0Q[G^T&>X#M#'N?[0A[@.T,>Y_M
M"GN`[0Q[@.T0@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#P
MX=+#````````````````\$<MZ0*0H.$H,)#E+""0Y8GA@^`#`%[A`,"@XP(P
MW.``4*#A,""0Y0%`H.$T$)#ER0^@X0(``"H!,)+B`R"@X0`0H>*I/J#A@#&#
MX0(PD^"@'J'@>`"5Y3B`A>(``%#C*."%Y2S`A>4P,(7E-!"%Y1\``!H_`%GC
M+@``VD"02>(I8Z#A`7"&X@=SA.`(,*#A0."$X@#`E.4$`)3E"!"4Y0P@E.40
M0(3B#@!4X0#`@^4$`(/E"!"#Y0P@@^40,(/B\___&@4`H.&T_/_K!P!4X>W_
M_QH&;6;@!I.)X`D@H.$'$*#A"`"@X>GS_^MXD(7E\(>]Z$!P8.('`%GA"7"@
ML0``B.`'(*#A!!"@X>#S_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'D$G@
M!T"$X)K\_^O.___J!'"@X>;__^KP02WI.'"!XB@@D>4P8)'E,H^_YJ(QH.$_
M,`/B`2"#X@%`H.$X`%+C?Q#@XP!0H.$V;[_F`@"'X`,0Q^<\``#:0"!BX@`0
MH.,J]/_K!`"@X8+\_^L'`*#A.""@XP`0H.,D]/_K!`"@X7!@A.5T@(3E>OS_
MZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4+,-3E
M!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$)
M,,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,T
MH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4
MY1,PQ>7P0;WH@?/_ZC@@8N(`$*#C[?/_Z\?__^KP1RWI`'"@X4A@G^5(4)_E
M!F"/X`50C^`%8$;@`8"@X0*0H.%9\__K1F&PX?"'O0@`0*#C!#"5Y`D@H.$(
M$*#A!P"@X0%`A.(S_R_A!`!6X??__QKPA[WHQ$8!`+Q&`0`>_R_A"#"?Y0,P
MC^``,)/E?O/_ZJ!(`0`(0"WI"("]Z`$``@`Z````/0````H````]````#P``
M`#T````D````/0```#(````]`````@```#T````%````/0```!,````]````
M#0```#T````,````/0```",````]````$0```#T````F````/0````$````]
M````%P```#T````(````/0````D````]```````````````O=&UP`````"X`
M``!005)?5$U01$E2``!414U01$E2`%1-4`!54T52`````%5315).04U%````
M`"5S+R5S````+P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO
M)7,`97AE`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S
M``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)5
M1P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!
M3%]435!$25(```!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``
M``!005)?0TQ%04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R
M>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R
M;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````
M)7,E<W1E;7`M)74M)74E<P````!!4D=6`````!@```!P97)L`````%!!4CHZ
M4&%C:V5R.CI615)324].`````#$N,#4P````56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``
M+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF
M("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E
M;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P
M*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R
M96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT
M9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D[
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T
M(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I
M.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE
M(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@
M)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`````'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``````A(`0`02`$``````!1(`0`82`$`($@!`*1(
M`0`H2`$``````"Q(`0`T2`$``````#H````]````"@```#T````/````/0``
M`"0````]````,@```#T````"````/0````4````]````$P```#T````-````
M/0````P````]````(P```#T````1````/0```"8````]`````0```#T````7
M````/0````@````]````"0```#T``````````````$23_W\!````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````R!H!`*`:`0```````0``
M`$<#```!````5P,```$```!G`P```0```'$#```,````A!0!``T```!L1P$`
M&0```,R-`@`;````!````!H```#0C0(`'`````0```#U_O]OM`$!``4````4
M#`$`!@```&0%`0`*````^00```L````0````%0`````````#````Z(X"``(`
M```0`@``%````!$````7````=!(!`!$```!$$@$`$@```#`````3````"```
M`!X````(````^___;P$```#^__]OY!$!`/___V\#````\/__;PX1`0``````
M``````````````````````````````````````````````````````````#8
MC0(```````````"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4
M`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!
M`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`
MD!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0
M%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4
M`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!`)`4`0"0%`$`D!0!
M`)`4`0````````````````#_____0$L!`$=#0SH@*%)A<W!B:6%N(#$P+C(N
M,"TQ-BMR<&DQ*2`Q,"XR+C``02X```!A96%B:0`!)`````4V``8&"`$)`0H"
M$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``&0```````````````0`````````3
M````!P````(```!P`0$`<`$``"0```````````````0`````````)@````<`
M```"````E`$!`)0!```@```````````````$`````````#0```#V__]O`@``
M`+0!`0"T`0``L`,```4`````````!`````0````^````"P````(```!D!0$`
M9`4``+`&```&`````0````0````0````1@````,````"````%`P!`!0,``#Y
M!``````````````!`````````$X```#___]O`@````X1`0`.$0``U@````4`
M`````````@````(```!;````_O__;P(```#D$0$`Y!$``&`````&`````P``
M``0`````````:@````D````"````1!(!`$02```P````!0`````````$````
M"````',````)````0@```'02`0!T$@``$`(```4````6````!`````@```!\
M`````0````8```"$%`$`A!0```P```````````````0`````````=P````$`
M```&````D!0!`)`4```L`P`````````````$````!````((````!````!@``
M`,`7`0#`%P``K"\`````````````"`````````"(`````0````8```!L1P$`
M;$<```@```````````````0`````````C@````$````"````=$<!`'1'```D
M/P`````````````$`````````)8````!``!P@@```)B&`0"8A@``"`````T`
M````````!`````````"A`````0````(```"@A@$`H(8```0`````````````
M``0`````````JP````X````#````S(T"`,R-```$```````````````$````
M!````+<````/`````P```-"-`@#0C0``!```````````````!`````0```##
M`````0````,```#4C0(`U(T```0```````````````0`````````T`````8`
M```#````V(T"`-B-```0`0``!@`````````$````"````-D````!`````P``
M`.B.`@#HC@``&`$`````````````!`````0```#>`````0````,`````D`(`
M`)```!````````````````0`````````Y`````@````#````$)`"`!"0```L
M$``````````````(`````````.D````!````,``````````0D```)@``````
M`````````0````$```#R`````P``<```````````-I```"\`````````````
M``$``````````0````,``````````````&60```"`0`````````````!````
$````````
